# CHANGELOG


## v0.2.2 (2025-07-16)

### Bug Fixes

- Set js log to debugging
  ([`23301e1`](https://github.com/bec-project/qtmonaco/commit/23301e15d12a3d6b19f8571c5d492da62cca5472))


## v0.2.1 (2025-07-16)

### Bug Fixes

- Fix js mapping and cleanup
  ([`97ab296`](https://github.com/bec-project/qtmonaco/commit/97ab296db83b3cde8dc093360272d1f384fd84a2))

### Documentation

- Update readme with public api
  ([`b6c513f`](https://github.com/bec-project/qtmonaco/commit/b6c513f42bedb8ad006df0aa161c34d838831666))


## v0.2.0 (2025-07-16)

### Bug Fixes

- Fix js interface
  ([`5a32eec`](https://github.com/bec-project/qtmonaco/commit/5a32eec78440ff9b9abb73a2ae53aa5f47494f09))

### Features

- Add method to enable / disable the minimap
  ([`d89b6a8`](https://github.com/bec-project/qtmonaco/commit/d89b6a84c8ba6e68e99dca65b5567d289e00848b))


## v0.1.6 (2025-07-16)

### Bug Fixes

- Build js artifacts and include them in the release
  ([`8d5df31`](https://github.com/bec-project/qtmonaco/commit/8d5df31bbf1907a300a259c7d99869ba78032254))


## v0.1.5 (2025-07-11)

### Bug Fixes

- Update resource handling and build configuration for RCC files
  ([`72ea277`](https://github.com/bec-project/qtmonaco/commit/72ea277051f6d0920876fd826ffd65067a94b516))


## v0.1.4 (2025-07-11)

### Bug Fixes

- Remove unnecessary command from rcc file build step
  ([`92f3901`](https://github.com/bec-project/qtmonaco/commit/92f390178a75dcc45433af0d64fe6e69c9c6e4b7))

- Update build configuration to include all files and specify artifacts
  ([`dac680b`](https://github.com/bec-project/qtmonaco/commit/dac680bbb565fe25623ddc53c766d7468567e180))

### Continuous Integration

- Add debugging output
  ([`bfc4dc7`](https://github.com/bec-project/qtmonaco/commit/bfc4dc75854d4a9c021af590759cb4722314d601))


## v0.1.3 (2025-07-11)

### Bug Fixes

- Build
  ([`33d5d70`](https://github.com/bec-project/qtmonaco/commit/33d5d70b0952e24cb693532f112aa42b4e4ef9fa))


## v0.1.2 (2025-07-11)

### Bug Fixes

- Fix rcc location within build
  ([`31e288f`](https://github.com/bec-project/qtmonaco/commit/31e288f4d2b2c4d7f5872616183a2db5d07a68c2))


## v0.1.1 (2025-07-11)

### Bug Fixes

- Fix release step
  ([`182c7de`](https://github.com/bec-project/qtmonaco/commit/182c7dec74c46437e1a56d03c53b9992b135ad90))


## v0.1.0 (2025-07-11)

### Continuous Integration

- Add pypi build and upload
  ([`25ea54a`](https://github.com/bec-project/qtmonaco/commit/25ea54a80e6fd54a215cb3679ca80e8e49c8e97b))

- Init
  ([`0b5ef18`](https://github.com/bec-project/qtmonaco/commit/0b5ef1858bc95ec93e6c8abb993b1e01f8772cac))

### Features

- Add qt bridge
  ([`7361271`](https://github.com/bec-project/qtmonaco/commit/73612710b57424234900863606fe3aa74ad6754f))
